@@ -3,11 +3,11 @@
 #' STV Vote Counting
 #'
 #' Functions in this package are designed to clean, validate, and count single transferable votes.
-#' @docType package
 #' @name STV-package
 #' @author Jay Emerson (expand this)
 #' @importFrom utils tail write.table
-NULL
+#' @importFrom methods is
+"_PACKAGE"
 
 #' ballots data contains rankings of 44 candidates by 489 people.
 #' 10 rows are black, which will prompt an error. This data follows the structure of a 2016 Yale faculty senate election, but vote choices have been permuted and candidate names have been removed.
